==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaCzynnoscKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class PlanWsparciaCzynnoscKey extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_CZYNNOSC.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long czynnoscId;

    /**
     * PLAN_WSPARCIA_CZYNNOSC.PLAN_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long planId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_CZYNNOSC.CZYNNOSC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:41
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PLAN_WSPARCIA_CZYNNOSC.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @return PLAN_WSPARCIA_CZYNNOSC.PLAN_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * PLAN_WSPARCIA_CZYNNOSC.PLAN_ID
     *
     * @param planId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaCzynnoscKey other = (PlanWsparciaCzynnoscKey) that;
        return (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()))
            && (this.getPlanId() == null ? other.getPlanId() == null : this.getPlanId().equals(other.getPlanId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        result = prime * result + ((getPlanId() == null) ? 0 : getPlanId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append(", planId=").append(planId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaCzynnoscKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class PlanWsparciaCzynnoscKey extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_CZYNNOSC.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long czynnoscId;

    /**
     * PLAN_WSPARCIA_CZYNNOSC.PLAN_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long planId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_CZYNNOSC.CZYNNOSC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:45
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PLAN_WSPARCIA_CZYNNOSC.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @return PLAN_WSPARCIA_CZYNNOSC.PLAN_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * PLAN_WSPARCIA_CZYNNOSC.PLAN_ID
     *
     * @param planId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaCzynnoscKey other = (PlanWsparciaCzynnoscKey) that;
        return (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()))
            && (this.getPlanId() == null ? other.getPlanId() == null : this.getPlanId().equals(other.getPlanId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        result = prime * result + ((getPlanId() == null) ? 0 : getPlanId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append(", planId=").append(planId);
        sb.append("]");
        return sb.toString();
    }
}
